@@ -23,9 +23,6 @@ Cov_LW02 <- nonlin_shrinkLW(X)
 SCM <- Sigma_sample_estimator(X)
 Cov_BGP14 <- CovShrinkBGP14(n=n, TM=Sigma, SCM=SCM)$S
 
-# BGP16 doesn't converge!
-# iCov_BGP16 <- InvCovShrinkBGP16(n=n, p=p,TM=Sigma, iSCM=SCM)
-
 #### tests
 test_that("All cov estimators produce matrices", {
 
@@ -38,3 +35,35 @@ test_that("All cov estimators are close to the real covariance", {
   expect_lte(sum(abs(Cov_LW02-Sigma)[1:6,1:6]), 6/100*5)
   expect_lte(sum(abs(Cov_BGP14-Sigma)[1:6,1:6]), 6/100*5)
 })
+
+test_that("nonlin_shrinkLW works when c>1", {
+
+  n<-100; c<-4.2; p<-c*n; mu <- rep(0, p)
+
+  set.seed(1)
+  Sigma <- HDShOP::RandCovMtrx(p=p)
+  set.seed(1)
+  X <- t(MASS::mvrnorm(n=n, mu=mu, Sigma=Sigma))
+
+  LW <- nonlin_shrinkLW(X)
+  min_eig <- min(eigen(LW)$values)
+
+  expect_gte(min_eig, 0.05)
+  expect_is(LW , class="matrix")
+
+  #### the same with another c and seed
+
+  n<-100; c<-2; p<-c*n; mu <- rep(0, p)
+
+  set.seed(2)
+  Sigma <- HDShOP::RandCovMtrx(p=p)
+  set.seed(2)
+  X <- t(MASS::mvrnorm(n=n, mu=mu, Sigma=Sigma))
+
+  LW <- nonlin_shrinkLW(X)
+  min_eig <- min(eigen(LW)$values)
+
+  expect_gte(min_eig, 0.05)
+  expect_is(LW , class="matrix")
+})
+
